@@ -362,8 +362,15 @@ def pytest_load_initial_conftests(
 
 @pytest.hookimpl(trylast=True)
 def pytest_configure(config: pytest.Config) -> None:
-    # Allow Django settings to be configured in a user pytest_configure call,
-    # but make sure we call django.setup()
+    if config.getoption("version", 0) > 0 or config.getoption("help", False):
+        return
+
+    # Normally Django is set up in `pytest_load_initial_conftests`, but we also
+    # allow users to not set DJANGO_SETTINGS_MODULE/`--ds` and instead
+    # configure the Django settings in a `pytest_configure` hookimpl using e.g.
+    # `settings.configure(...)`. In this case, the `_setup_django` call in
+    # `pytest_load_initial_conftests` only partially initializes Django, and
+    # it's fully initialized here.
     _setup_django(config)
 
 
@@ -470,8 +477,7 @@ def pytest_collection_modifyitems(items: list[pytest.Item]) -> None:
 
 @pytest.fixture(autouse=True, scope="session")
 def django_test_environment(request: pytest.FixtureRequest) -> Generator[None, None, None]:
-    """
-    Ensure that Django is loaded and has its testing environment setup.
+    """Setup Django's test environment for the testing session.
 
     XXX It is a little dodgy that this is an autouse fixture.  Perhaps
         an email fixture should be requested in order to be able to
@@ -481,7 +487,6 @@ def django_test_environment(request: pytest.FixtureRequest) -> Generator[None, N
         we need to follow this model.
     """
     if django_settings_is_configured():
-        _setup_django(request.config)
         from django.test.utils import setup_test_environment, teardown_test_environment
 
         debug_ini = request.config.getini("django_debug_mode")
